@@ -14,6 +14,7 @@
 #' @param subplot String.
 #' @param subp_cond String. 
 #' @param lulc String. 
+#' @param cond_dwm_calc String. 
 #' @param ... For extendibility.
 #' @return A list of user-supplied parameters and parameter values for strata.
 #' @author Grayson W. White
@@ -24,7 +25,8 @@
 
 popTableIDs <- function(cond="PLT_CN", plt="CN", tree="PLT_CN", seed="PLT_CN",
                         vsubpspp="PLT_CN", vsubpstr="PLT_CN", subplot="PLT_CN",
-                        subp_cond="PLT_CN", lulc="PLT_CN",...) {
+                        subp_cond="PLT_CN", lulc="PLT_CN", 
+                        cond_dwm_calc="PLT_CN", ...) {
   # Check input parameters
   input.params <- names(as.list(match.call()))[-1]
   formallst <- c(names(formals(popTableIDs)))
