@@ -36,6 +36,8 @@
 #' (SUBP_COND).
 #' @param lulc DF/DT, R object, comma-delimited file(*.csv), or layer in dsn.
 #' Land use/Land cover data with current and previous observations.
+#' @param cond_dwm_calc DF/DT, R object, comma-delimited file(*.csv), or layer 
+#' in dsn. Calculated down woody material.
 #' @param ... For extendibility.
 #' @return A list of user-supplied parameters and parameter values for strata.
 #' @author Grayson W. White
@@ -47,7 +49,8 @@
 popTables <- function(cond=NULL, plt=NULL, 
                       tree=NULL, seed=NULL, 
                       vsubpspp=NULL, vsubpstr=NULL, invsubp=NULL,
-                      subplot=NULL, subp_cond=NULL, lulc=NULL, ...) {
+                      subplot=NULL, subp_cond=NULL, lulc=NULL, 
+                      cond_dwm_calc=NULL, ...) {
   # Check input parameters
   input.params <- names(as.list(match.call()))[-1]
   formallst <- c(names(formals(popTables)))
